@@ -626,7 +626,7 @@ public class TreeView extends Container {
 				evtMap.initialize(this, TreeViewEvent.Type.EXPAND_COLLAPSE_CURSOR_ROW);
 				evtMap.initialize(this, TreeViewEvent.Type.ROW_ACTIVATED);
 				evtMap.initialize(this, TreeViewEvent.Type.ROW_COLLAPSED);
-				evtMap.initialize(this, TreeViewEvent.Type.ROW_COLLAPSED);
+				evtMap.initialize(this, TreeViewEvent.Type.ROW_EXPANDED);
 				evtMap.initialize(this, TreeViewEvent.Type.SELECT_ALL);
 				evtMap.initialize(this, TreeViewEvent.Type.SELECT_CURSOR_PARENT);
 				evtMap.initialize(this, TreeViewEvent.Type.SELECT_CURSOR_ROW);
@@ -778,6 +778,32 @@ public class TreeView extends Container {
 		return et;
 	}
 
+	public PosInfo getPathAtPos(int x, int y) {
+	    int[] path = new int[1];
+	    int[] column = new int[1];
+	    int[] cellX = new int[1];
+	    int[] cellY = new int[1];
+	    if (gtk_tree_view_get_path_at_pos(getHandle(),x,y,path,column,cellX,cellY)) {
+	        PosInfo pos = new PosInfo(new TreePath(path[0]), new TreeViewColumn(column[0]), 
+	                cellX[0], cellY[0]);
+	        return pos;
+	    } else
+	        return null;
+	}
+	
+	public static class PosInfo {
+	    public int cellX;
+	    public int cellY;
+	    public TreePath path;
+	    public TreeViewColumn column;
+	    public PosInfo(TreePath path, TreeViewColumn column, int x, int y) {
+	        this.path = path;
+	        this.column = column;
+	        this.cellX = x;
+	        this.cellY = y;
+	    }
+	}
+	
 	private static EventMap evtMap = new EventMap();
 	static {
 		addEvents(evtMap);
@@ -844,7 +870,7 @@ public class TreeView extends Container {
 	native static final protected void gtk_tree_view_set_cursor_on_cell(int treeView, int path, int focusColumn, int focusCell, boolean startEditin);
 	native static final protected void gtk_tree_view_get_cursor(int treeView, int[] path, int[] focusColumn);
 //	native static final protected int gtk_tree_view_get_bin_window(int treeView);
-//	native static final protected boolean gtk_tree_view_get_path_at_pos(int treeView, int x, int y, int[] path, int[] column, int[] cellX, int[] cellY);
+	native static final protected boolean gtk_tree_view_get_path_at_pos(int treeView, int x, int y, int[] path, int[] column, int[] cellX, int[] cellY);
 //	native static final protected int gtk_tree_view_get_cell_area(int treeView, int path, int column);
 //	native static final protected int gtk_tree_view_get_background_area(int treeView, int path, int column);
 //	native static final protected int gtk_tree_view_get_visible_rect(int treeView);
